function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import color from 'color';
import * as React from 'react';
import { Platform, StyleSheet, TouchableWithoutFeedback, View } from 'react-native';
import { withTheme } from '../../core/theming';
import { white } from '../../styles/colors';
import Text from '../Typography/Text';

/**
 * A component used to display a title and optional subtitle in an appbar.
 *
 * <div class="screenshots">
 *   <figure>
 *     <img class="medium" src="screenshots/appbar-content.png" />
 *   </figure>
 * </div>
 *
 * ## Usage
 * ```js
 * import * as React from 'react';
 * import { Appbar } from 'react-native-paper';
 *
 * const MyComponent = () => (
 *     <Appbar.Header>
 *        <Appbar.Content title="Title" subtitle={'Subtitle'} />
 *     </Appbar.Header>
 * );
 *
 * export default MyComponent;
 * ```
 */
const AppbarContent = /*#__PURE__*/React.forwardRef((_ref, ref) => {
  let {
    color: titleColor = white,
    subtitle,
    subtitleStyle,
    onPress,
    style,
    titleRef,
    titleStyle,
    theme,
    title,
    allowTitleFontScaling,
    allowSubtitleFontScaling,
    ...rest
  } = _ref;
  const {
    fonts
  } = theme;
  const subtitleColor = color(titleColor).alpha(0.7).rgb().string();
  let titleElement = null;
  let subtitleElement = null;
  const titleAccessibilityTraits = rest.accessible ? {
    accessible: false
  } : {
    accessible: true,
    accessibilityTraits: 'header',
    accessibilityRole: Platform.OS === 'web' ? 'heading' : 'header'
  };
  const subtitleAccessibilityTraits = rest.accessible ? {
    accessible: false
  } : {};

  if (title) {
    if (typeof title === 'string') {
      titleElement = /*#__PURE__*/React.createElement(Text, _extends({
        ref: titleRef,
        style: [{
          color: titleColor,
          ...(Platform.OS === 'ios' ? fonts.regular : fonts.medium)
        }, styles.title, titleStyle],
        numberOfLines: 1,
        allowFontScaling: allowTitleFontScaling
      }, titleAccessibilityTraits), title);
    } else {
      titleElement = title;
    }
  }

  if (subtitle) {
    if (typeof subtitle === 'string') {
      subtitleElement = /*#__PURE__*/React.createElement(Text, _extends({
        style: [styles.subtitle, {
          color: subtitleColor
        }, subtitleStyle],
        numberOfLines: 1,
        allowFontScaling: allowSubtitleFontScaling
      }, subtitleAccessibilityTraits), subtitle);
    } else {
      subtitleElement = subtitle;
    }
  }

  const textView = /*#__PURE__*/React.createElement(View, _extends({
    style: [styles.container, style]
  }, rest, {
    ref: ref
  }), titleElement, subtitleElement);

  if (onPress) {
    return /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
      onPress: _event => onPress()
    }, textView);
  } else {
    return textView;
  }
});
AppbarContent.displayName = 'Appbar.Content';
const styles = StyleSheet.create({
  container: {
    flex: 1,
    paddingHorizontal: 12
  },
  title: {
    fontSize: Platform.OS === 'ios' ? 17 : 20
  },
  subtitle: {
    fontSize: Platform.OS === 'ios' ? 11 : 14
  }
});
export default withTheme(AppbarContent); // @component-docs ignore-next-line

const AppbarContentWithTheme = withTheme(AppbarContent); // @component-docs ignore-next-line

export { AppbarContentWithTheme as AppbarContent };
//# sourceMappingURL=AppbarContent.js.map